==> skellycam-2023.1.1027-py3-none-any.whl: skellycam/qt_gui/css/qt_css_stylesheet.py <==
QT_CSS_STYLE_SHEET_STRING = """
                            QMainWindow {
                                background-color: #5a6283;                                
                            } 


                            QPushButton {
                                        font-size: 24px;
                                        font-weight: bold;
                                        font-family: "Dosis", sans-serif;
                                        border-radius: 4px;
                                        border: 2px solid #29394a;
                                        background-color: #29394a;
                                        color: #dddddd;
                                        border-width: 2px;                                                                                
                                        }
                            QPushButton:focus {
                                        border: 2px solid #ff40aa;
                                        }
                            QPushButton:disabled {
                                        border: 2px solid #444444;
                                        background-color: #414C58;
                                        color: #aaaaaa;
                                        }
                            QPushButton:hover {
                                        background-color: #29696a;
                                        border: 3px solid #ff40aa;
                                        }

                            QParameterTreeWidget {
                                background-color: #ff0000;
                                color: #ffffff;

                            }
                            QTreeView {
                                        background-color: #7983b1;
                                        alternate-background-color: #a3b1ed;
                                        color: #222222;
                                        font-weight: bold;
                            }                            
                            QTreeView::item:has-children {
                                background-color: '#05100f';
                                color: #ffffff;
                            }
                            QTreeView::item:selected {
                                background-color: #18294a;
                            }
                            QTreeView::item:selected:active {
                                background-color: rgb(92, 53, 102);
                            }                        
                            QTreeView::item:hover {
                                background-color: #378e90;
                            }    
                            """

==> skellycam-2023.1.1044-py3-none-any.whl: skellycam/qt_gui/css/qt_css_stylesheet.py <==
QT_CSS_STYLE_SHEET_STRING = """
                            QMainWindow {
                                background-color: #5a6283;                                
                            } 


                            QPushButton {
                                        font-size: 24px;
                                        font-weight: bold;
                                        font-family: "Dosis", sans-serif;
                                        border-radius: 4px;
                                        border: 2px solid #29394a;
                                        background-color: #29394a;
                                        color: #dddddd;
                                        border-width: 2px;                                                                                
                                        }
                            QPushButton:focus {
                                        border: 2px solid #378e90;
                                        }
                            QPushButton:disabled {
                                        border: 2px solid #444444;
                                        background-color: #414C58;
                                        color: #aaaaaa;
                                        }
                            QPushButton:hover {
                                        background-color: #29696a;
                                        }
                            QParameterTreeWidget {
                                background-color: #ff0000;
                                color: #ffffff;
                            }
                            QTreeView {
                                        background-color: #7983b1;
                                        alternate-background-color: #a3b1ed;
                                        color: #222222;
                                        font-weight: bold;
                            }                            
                            QTreeView::item:has-children {
                                background-color: '#05100f';
                                color: #ffffff;
                            }
                            QTreeView::item:selected {
                                background-color: #18294a;
                            }
                            QTreeView::item:selected:active {
                                background-color: rgb(92, 53, 102);
                            }                        
                            QTreeView::item:hover {
                                background-color: #378e90;
                            }    
                            """
